@@ -1,12 +1,10 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors;
-# git description: v0.007-10-gf16ab82
-$Dist::Zilla::Plugin::Git::Contributors::VERSION = '0.008';
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.008-6-g8d4d708
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
 # vim: set ts=8 sw=4 tw=78 et :
-
+$Dist::Zilla::Plugin::Git::Contributors::VERSION = '0.009';
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
@@ -89,14 +87,16 @@ sub _contributors
     my @paths = $self->paths;
     unshift @paths, '--' if @paths;
 
-    my @data = $self->_git(shortlog =>
-        {
-            email => 1,
-            summary => 1,
-            $self->order_by eq 'commits' ? ( numbered => 1 ) : (),
-        },
-        'HEAD', @paths,
-    );
+    my @data = try {
+        $self->_git(shortlog =>
+            {
+                email => 1,
+                summary => 1,
+                $self->order_by eq 'commits' ? ( numbered => 1 ) : (),
+            },
+            'HEAD', @paths,
+        );
+    };
 
     my @contributors = map { utf8::decode($_); m/^\s*\d+\s*(.*)$/g; } @data;
 
@@ -176,7 +176,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
